Hello community,

here is the log from the commit of package headmore for openSUSE:Factory 
checked in at 2017-02-10 10:04:00
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/headmore (Old)
 and      /work/SRC/openSUSE:Factory/.headmore.new (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "headmore"

Changes:
--------
--- /work/SRC/openSUSE:Factory/headmore/headmore.changes        2016-11-03 
11:14:12.000000000 +0100
+++ /work/SRC/openSUSE:Factory/.headmore.new/headmore.changes   2017-02-10 
10:04:28.622740579 +0100
@@ -1,0 +2,7 @@
+Thu Feb  9 08:11:14 UTC 2017 - h...@suse.com
+
+- Upgrade to release 1.2 with exactly one feature enhancement:
+  * Local mouse pointer can be toggled with space bar, this makes
+    mouse pointer visible in case it is not drawn by VNC server.
+
+-------------------------------------------------------------------

Old:
----
  headmore-1.1.1.tar.gz

New:
----
  headmore-1.2.tar.gz

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ headmore.spec ++++++
--- /var/tmp/diff_new_pack.VRlfMi/_old  2017-02-10 10:04:29.154665354 +0100
+++ /var/tmp/diff_new_pack.VRlfMi/_new  2017-02-10 10:04:29.158664788 +0100
@@ -1,7 +1,6 @@
 #
 # spec file for package headmore
 #
-# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
 # Copyright (c) 2016 Howard Guo <guohou...@gmail.com>
 #
 # All modifications and additions to the file contributed by third parties
@@ -16,22 +15,17 @@
 # Please submit bugfixes or comments via http://bugs.opensuse.org/
 #
 
-
 Name:           headmore
-Version:        1.1.1
+Version:        1.2
 Release:        0
-Summary:        VNC client for character terminals
 License:        GPL-3.0
-Group:          Productivity/Networking/Other
+Summary:        VNC client for character terminals
 Url:            https://github.com/HouzuoGuo/headmore
+Group:          Productivity/Networking/Other
 Source:         %{name}-%{version}.tar.gz
-BuildRequires:  libgcrypt-devel
-BuildRequires:  libjpeg8-devel
-BuildRequires:  libopenssl-devel
-BuildRequires:  libpng16-compat-devel
 BuildRequires:  pkg-config
-BuildRequires:  pkgconfig(caca)
-BuildRequires:  pkgconfig(libvncclient)
+BuildRequires:  pkgconfig(caca) pkgconfig(libvncclient)
+BuildRequires:  libgcrypt-devel libjpeg8-devel libopenssl-devel 
libpng16-compat-devel
 
 %description
 headmore is a client for Virtual Network Computing (VNC),

++++++ headmore-1.1.1.tar.gz -> headmore-1.2.tar.gz ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/headmore-1.1.1/README.md new/headmore-1.2/README.md
--- old/headmore-1.1.1/README.md        2016-11-02 09:26:31.000000000 +0100
+++ new/headmore-1.2/README.md  2017-02-09 09:07:57.000000000 +0100
@@ -32,7 +32,7 @@
 You are most welcomed to contribute code and file bug report, feature request, 
and questions in the project's [issues 
page](https://github.com/HouzuoGuo/headmore/issues), you may also direct any 
inquiry to the author in [Email](mailto:guohou...@gmail.com).
 
 ## License
-Copyright (c) 2016 Howard Guo <guohou...@gmail.com>
+Copyright (c) 2017 Howard Guo <guohou...@gmail.com>
 
 This program is free software; you can redistribute it and/or modify it under 
the terms of the GNU General Public License as published by the Free Software 
Foundation; either version 3 of the License, or (at your option) any later 
version.
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/headmore-1.1.1/geo.c new/headmore-1.2/geo.c
--- old/headmore-1.1.1/geo.c    2016-11-02 09:26:31.000000000 +0100
+++ new/headmore-1.2/geo.c      2017-02-09 09:07:57.000000000 +0100
@@ -1,8 +1,8 @@
 #include <string.h>
 #include "geo.h"
 
-struct geo_facts geo_facts_of(struct vnc *vnc, caca_display_t * disp,
-                             caca_canvas_t * view)
+struct geo_facts
+geo_facts_of(struct vnc *vnc, caca_display_t * disp, caca_canvas_t * view)
 {
        struct geo_facts ret;
        ret.px_width = caca_get_display_width(disp);
@@ -55,9 +55,9 @@
            (g->zoom <
             0) ? 1.0 / g->zoom_lvls[-g->zoom] : g->zoom_lvls[g->zoom];
        g->zoom_y =
-           g->zoom_x * facts.ch_width / facts.ch_height *
-           facts.vnc_height / facts.vnc_width * facts.ch_height /
-           facts.ch_width * facts.px_width / facts.px_height;
+           g->zoom_x * facts.ch_width / facts.ch_height * facts.vnc_height /
+           facts.vnc_width * facts.ch_height / facts.ch_width *
+           facts.px_width / facts.px_height;
 
        if (g->zoom_y > g->zoom_x) {
                float tmp = g->zoom_x;
@@ -90,8 +90,8 @@
        }
 }
 
-void geo_move_mouse(struct geo *g, struct geo_facts facts, int step_x,
-                   int step_y)
+void
+geo_move_mouse(struct geo *g, struct geo_facts facts, int step_x, int step_y)
 {
        int speed = g->mouse_speed[g->zoom];
        g->mouse_x += step_x * speed;
@@ -117,8 +117,8 @@
        g->view_y = (float)g->mouse_y / (float)facts.vnc_height;
 }
 
-struct geo_dither_params geo_get_dither_params(struct geo *g,
-                                              struct geo_facts facts)
+struct geo_dither_params
+geo_get_dither_params(struct geo *g, struct geo_facts facts)
 {
        struct geo_dither_params ret;
        ret.facts = facts;
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/headmore-1.1.1/headmore.1 new/headmore-1.2/headmore.1
--- old/headmore-1.1.1/headmore.1       2016-11-02 09:26:31.000000000 +0100
+++ new/headmore-1.2/headmore.1 2017-02-09 09:07:57.000000000 +0100
@@ -34,6 +34,10 @@
 .B Q, E
 Zoom out or in on the viewer.
 .
+.TP
+.B Space bar
+Toggle display mouse pointer locally. Mouse pointer is always displayed 
locally if current zoom is very far out.
+.
 
 .P
 And the right hand side controls are:
@@ -117,4 +121,4 @@
 You are most welcomed to file bug report, feature request, and questions in 
the project's Github page (https://github.com/HouzuoGuo/headmore), you may also 
direct any inquiry to the author in Email.
 
 .SH AUTHOR
-Howard Guo <guohou...@gmail.com>, 2016
+Howard Guo <guohou...@gmail.com>, 2017
Binary files old/headmore-1.1.1/key-map.png and new/headmore-1.2/key-map.png 
differ
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/headmore-1.1.1/viewer.h new/headmore-1.2/viewer.h
--- old/headmore-1.1.1/viewer.h 2016-11-02 09:26:31.000000000 +0100
+++ new/headmore-1.2/viewer.h   2017-02-09 09:07:57.000000000 +0100
@@ -31,6 +31,7 @@
        bool disp_help, input2vnc;
        bool hold_lctrl, hold_lshift, hold_lalt, hold_lsuper, hold_ralt,
            hold_rshift, hold_rctrl;
+       bool draw_mouse_pointer;
        bool mouse_left, mouse_middle, mouse_right;
 };
 


Reply via email to
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/headmore-1.1.1/viewer.c new/headmore-1.2/viewer.c
--- old/headmore-1.1.1/viewer.c 2016-11-02 09:26:31.000000000 +0100
+++ new/headmore-1.2/viewer.c   2017-02-09 09:07:57.000000000 +0100
@@ -22,6 +22,7 @@
        "~     Click back-tick in VNC       ",
        "wasd  Pan viewer                   ",
        "q/e   Zoom out/in                  ",
+       "Space Toggle display mouse pointer ",
        "============ RIGHT HAND ===========",
        "F10  Quit                          ",
        "ijkl Move mouse cursor             ",
@@ -45,6 +46,7 @@
 
 bool viewer_init(struct viewer * v, struct vnc * vnc)
 {
+       /* All bool switches are off by default */
        memset(v, 0, sizeof(struct viewer));
        /* Initialise visuals */
        v->view = caca_create_canvas(0, 0);
@@ -170,14 +172,19 @@
        /*
         * Mouse cursors are usually wider than 14 pixels. If it will not take
         * more than 5 characters to draw the cusor, then consider it very
         * difficult to spot on the VNC canvas, and draw an easy to spot block
         * right there.
there.
         */
+       int mouse_ch_x = geo_dither_ch_px_x(&params, v->geo.mouse_x);
+       int mouse_ch_y = geo_dither_ch_px_y(&params, v->geo.mouse_y);
        if (geo_dither_numch_x(&params, 12) < 5) {
                caca_set_color_ansi(v->view, CACA_WHITE, CACA_RED);
-               int ch_x = geo_dither_ch_px_x(&params, v->geo.mouse_x);
-               int ch_y = geo_dither_ch_px_y(&params, v->geo.mouse_y);
-               caca_fill_box(v->view, ch_x - 1, ch_y - 1, 3, 3, '*');
+               caca_fill_box(v->view, mouse_ch_x - 1, mouse_ch_y - 1, 3, 3,
+                             '*');
+       }
+       /* Draw local mouse pointer */
+       if (v->draw_mouse_pointer) {
+               caca_set_color_ansi(v->view, CACA_WHITE, CACA_RED);
+               caca_put_char(v->view, mouse_ch_x, mouse_ch_y, '*');
        }
        viewer_disp_status(v);
        if (v->disp_help) {
@@ -440,6 +447,9 @@
                /* Click back-tick (96 in ASCII) in VNC */
                viewer_vnc_click_key(v, 96);
                break;
+       case ' ':
+               v->draw_mouse_pointer = !v->draw_mouse_pointer;
+               break;
                /* Right hand */
        case 'i':
        case 'I':
@@ -170,14 +172,19 @@
         * Mouse cursors are usually wider than 14 pixels. If it will not take
         * more than 5 characters to draw the cusor, then consider it very
-        * difficult to spot on the VNC canvas, and draw an easy to spot block
-        * right there.
+        * difficult to spot on the VNC canvas, and draw a red block right 
there.
         */